# AppModule: emule.py
# Scripts documentation in Spanish

import appModuleHandler
import api
import ui
import speech
import oleacc
import winUser
import NVDAObjects.IAccessible
from NVDAObjects.IAccessible import IAccessible



class PropertyPage:

    def getToolBar(self):
        return api.getStatusBar().simpleNext

    def getWhere(self):
        children=self.getToolBar().children
        for child in children:
            if child.IAccessibleStates==16:
                return child

    def getName(self):
        return self.getWhere().name

    def getChildID(self):
        return self.getWhere().IAccessibleChildID


    def getToolBarWindow(self):
        obj=self.getToolBar().simpleNext
        children=obj.children
        obj=None
        for child in children:
            if child.IAccessibleRole==oleacc.ROLE_SYSTEM_TOOLBAR:
                obj=child
        return obj


    def getHeader(self):
        obj=api.getFocusObject()
        if not obj.windowClassName==u'SysListView32':
            return None
        if obj.IAccessibleRole==oleacc.ROLE_SYSTEM_LISTITEM:
            obj=obj.parent
        location=obj.location
        if location and (len(location)==4):
		(left,top,width,height)=location
        else:
            return None
        obj=NVDAObjects.IAccessible.getNVDAObjectFromPoint(left, top)
#        obj=obj.parent.simpleFirstChild

        return obj



class AppModule(appModuleHandler.AppModule):



    def script_toolBar(self, gesture):
        p=PropertyPage()
        obj=p.getToolBar()
        obj.setFocus()
        api.moveMouseToNVDAObject(obj)
        api.setMouseObject(obj)
        speech.speakObject(obj)



    script_toolBar.__doc__=_("Lleva el foco a la barra de herramientas")


    def script_where(self, gesture):
        p=PropertyPage()
        ui.message("%s" % p.getName())


    script_where.__doc__=_("Indica la ventana seleccionada")


    def script_name(self, gesture):
        p=PropertyPage()
        if p.getWhere().IAccessibleChildID==6:
            obj=p.getToolBar().simpleNext.simpleNext.lastChild
        obj.setFocus()


    script_name.__doc__=_("Lleva el foco al campo nombre en la ventana Buscar")


    def script_searchList(self, gesture):
        p=PropertyPage()
        if p.getWhere().IAccessibleChildID==6:
            obj=p.getToolBar().simpleNext.simpleNext.lastChild
        children = obj.children
        for child in children:
            if child.IAccessibleRole==oleacc.ROLE_SYSTEM_LIST:
                obj=child
        obj.setFocus()
        api.moveMouseToNVDAObject(obj)
        api.setMouseObject(obj)

    script_searchList.__doc__=_("Lleva el foco a la lista de opciones de la ventana buscar, o a los campos de texto correspondientes a cada elemento de la lista")

    def script_results(self, gesture):
        p=PropertyPage()
        if p.getWhere().IAccessibleChildID==6:
            obj=p.getToolBar().simpleNext.firstChild
            children=obj.children
            for child in children:
                if child.IAccessibleRole==oleacc.ROLE_SYSTEM_TOOLBAR:
                    obj=child.firstChild
            api.moveMouseToNVDAObject(obj)
            api.setMouseObject(obj)
            winUser.mouse_event(winUser.MOUSEEVENTF_LEFTDOWN,0,0,None,None)
            winUser.mouse_event(winUser.MOUSEEVENTF_LEFTUP,0,0,None,None)


    script_results.__doc__=_("Lleva el foco a la lista de resultados en la ventana Buscar")


    def script_mainWindow(self, gesture):
        p=PropertyPage()
        obj=p.getToolBarWindow()
        obj.setFocus()
        api.moveMouseToNVDAObject(obj)
        api.setMouseObject(obj)

    script_mainWindow.__doc__=_("Lleva el foco a la barra de herramientas contextual para permitir el desplazamiento con el tabulador")


    def script_mainIRC(self, gesture):
        p=PropertyPage()
        obj=p.getToolBarWindow().simpleNext.simpleNext
        obj.setFocus()
        api.setFocusObject(obj)	
        speech.speakObject(obj)


    script_mainIRC.__doc__=_("Lleva el foco a la ventana de mensajes del chat")



    def script_header(self, gesture):
        p=PropertyPage()
        obj=p.getHeader()
        api.setNavigatorObject(obj)
        api.moveMouseToNVDAObject(obj)
        api.setMouseObject(obj)
        speech.speakObject(obj)



    script_header.__doc__=_("Lleva el navegador de objetos a los encabezados de columna de la lista actual")


    def statusBarObj(self, pos):
        obj=api.getStatusBar().simpleFirstChild
        for n in xrange(pos):
            obj=obj.simpleNext
        text=obj.name
        return text


    def script_statusBarFirstChild(self, gesture):
        ui.message(self.statusBarObj(0))

    script_statusBarFirstChild.__doc__=_("Lee el primer objeto de la barra de estado")


    def script_statusBarSecondChild(self, gesture):
        ui.message(self.statusBarObj(1))


    script_statusBarSecondChild.__doc__=_("Lee el segundo objeto de la barra de estado")


    def script_statusBarThirdChild(self, gesture):
        ui.message(self.statusBarObj(2))


    script_statusBarThirdChild.__doc__=_("Lee el tercer objeto de la barra de estado")


    def script_statusBarForthChild(self, gesture):
        ui.message(self.statusBarObj(3))


    script_statusBarForthChild.__doc__=_("Lee el cuarto objeto de la barra de estado")

    __gestures={"kb:control+shift+h": "toolBar", "kb:control+shift+t": "where", "kb:control+shift+n": "name", "kb:control+shift+p": "searchList", "kb:control+shift+b": "results", "kb:control+shift+z": "mainWindow", "kb:control+shift+o": "mainIRC", "kb:control+shift+l": "header", "kb:control+shift+q": "statusBarFirstChild", "kb:control+shift+w": "statusBarSecondChild", "kb:control+shift+e": "statusBarThirdChild", "kb:control+shift+r": "statusBarForthChild"}



